@@ -3,8 +3,6 @@
 #' @importFrom stats setNames
 #' @importFrom utils tail
 
-mergef<-function(x,y)
- factor(as.numeric(y)*length(levels(x))+as.numeric(x))
 
 pureMIM<-function(X,Y,k=3){
  miScores(X,Y)->mim
@@ -25,7 +23,7 @@ pureCMIM<-function(X,Y,k=3){
  #Conceptually wrong, but as defined by Fleuret
  scores<-ascores
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->w
+  joinf(X[,tail(selection,1)])->w
   scores[colnames(X)!=tail(selection,1)]->scores
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   newScores<-cmiScores(X,Y,w)
@@ -52,7 +50,7 @@ pureJMIM<-function(X,Y,k=3){
  fscores<-max(ascores)
  scores<-rep(Inf,ncol(X))
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->x
+  joinf(X[,tail(selection,1)])->x
   scores[colnames(X)!=tail(selection,1)]->scores
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   newScores<-jmiScores(X,Y,x) 
@@ -79,7 +77,7 @@ pureNJMIM<-function(X,Y,k=3){
  fscores<-max(ascores)
  scores<-rep(Inf,ncol(X))
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->x
+  joinf(X[,tail(selection,1)])->x
   scores[colnames(X)!=tail(selection,1)]->scores
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   newScores<-njmiScores(X,Y,x) 
@@ -113,7 +111,7 @@ pureCMI<-function(X,Y,k=3){
   selection<-c(selection,names(which.max(ascores)))
   fscores<-c(fscores,max(ascores))
 
-  Z<-mergef(Z,X[,which.max(ascores)])
+  Z<-joinf(Z,X[,which.max(ascores)])
   X<-X[,-which.max(ascores),drop=FALSE]
  }
  list(
@@ -130,7 +128,7 @@ pureJMI<-function(X,Y,k=3){
  fscores<-max(ascores)
  scores<-rep(0,ncol(X))
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->x
+  joinf(X[,tail(selection,1)])->x
   scores[colnames(X)!=tail(selection,1)]->scores
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   scores<-scores+jmiScores(X,Y,x) 
@@ -144,6 +142,43 @@ pureJMI<-function(X,Y,k=3){
  )
 }
 
+pureJMI3<-function(X,Y,k=3){
+ nX<-names(X)
+ X<-data.frame(X)
+ W<-c()
+ if(k>0){
+  s1<-miScores(X,Y)
+  fscores<-max(s1)
+  U<-X[,which.max(s1),drop=FALSE]
+  X<-X[,-which.max(s1),drop=FALSE]
+ }
+ if(k>1){
+  s2<-jmiScores(X,Y,U[,1])
+  fscores<-c(fscores,max(s2))
+  W<-X[,which.max(s2),drop=FALSE]
+  X<-X[,-which.max(s2),drop=FALSE]
+ }
+ if(k>2){
+  scores<-rep(0,ncol(X))
+  for(e in 3:k){
+   for(u in U){
+    scores<-scores+jmiScores(X,Y,joinf(u,W[,1]))
+   }
+   U<-cbind(U,W)
+   i<-which.max(scores)
+   fscores<-c(fscores,scores[i])
+   scores<-scores[-i]
+   W<-X[,i,drop=FALSE]
+   X<-X[,-i,drop=FALSE]
+  }
+ }
+ selection<-c(names(U),names(W))
+ list(
+  selection=setNames(match(selection,nX),selection),
+  score=setNames(fscores,selection)
+ )
+}
+
 pureMRMR<-function(X,Y,k=3){
  nX<-names(X)
  X<-data.frame(X)
@@ -152,7 +187,7 @@ pureMRMR<-function(X,Y,k=3){
  selection<-names(which.max(rel))
  fscores<-max(rel)
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->x
+  joinf(X[,tail(selection,1)])->x
   rel[colnames(X)!=tail(selection,1)]->rel
   red[colnames(X)!=tail(selection,1)]->red
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
@@ -178,7 +213,7 @@ pureDISR<-function(X,Y,k=3){
  fscores<-max(ascores)
  rep(0,ncol(X))->scores
  if(k>1) for(e in 1:(k-1)){
-  factor(X[,tail(selection,1)])->x
+  joinf(X[,tail(selection,1)])->x
   scores[colnames(X)!=tail(selection,1)]->scores
   X[,colnames(X)!=tail(selection,1),drop=FALSE]->X
   
